@@ -1,4 +1,4 @@
-/* $Id: actions.c,v 1.22.2.1.2.3 2011/01/19 12:03:56 imil Exp $ */
+/* $Id: actions.c,v 1.39 2011/02/06 10:55:36 imil Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -31,17 +31,6 @@
  */
 
 #include "pkgin.h"
-#if defined(__DragonFly__)
-#include <libutil.h>
-#elif defined(__NetBSD__)
-#include <util.h>
-#else
-#include <nbcompat/util.h>
-#endif
-
-#ifndef HN_AUTOSCALE
-#include "humanize_number.h"
-#endif
 
 #ifndef LOCALBASE
 #define LOCALBASE "/usr/pkg" /* see DISCLAIMER below */
@@ -73,29 +62,6 @@ check_yesno(void)
 	return r;
 }
 
-/* package removal */
-static void
-do_pkg_remove(Deptreehead *removehead)
-{
-	Pkgdeptree *premove;
-
-	SLIST_FOREACH(premove, removehead, next) {
-		/* file not available in the repository */
-	    	if (premove->file_size == -1)
-		    	continue;
-
-		if (premove->depname == NULL)
-			/* SLIST corruption, badly installed package */
-			continue;
-		printf(MSG_REMOVING, premove->depname);
-#ifdef DEBUG
-		printf("%s -f %s\n", PKG_DELETE, premove->depname);
-#else
-		fexec(PKG_DELETE, "-f", premove->depname, NULL);
-#endif
-	}
-}
-
 static void
 pkg_download(Deptreehead *installhead)
 {
@@ -146,6 +112,34 @@ pkg_download(Deptreehead *installhead)
 	} /* download loop */
 }
 
+/* package removal */
+static void
+do_pkg_remove(Deptreehead *removehead)
+{
+	Pkgdeptree *premove;
+
+/* send pkg_delete stderr to logfile */
+#ifdef HAVE_FREOPEN
+	(void)freopen(PKGIN_ERR_LOG, "a", stderr);
+#endif
+
+	SLIST_FOREACH(premove, removehead, next) {
+		/* file not available in the repository */
+	    	if (premove->file_size == -1)
+		    	continue;
+
+		if (premove->depname == NULL)
+			/* SLIST corruption, badly installed package */
+			continue;
+		printf(MSG_REMOVING, premove->depname);
+#ifdef DEBUG
+		printf("%s -f %s\n", PKG_DELETE, premove->depname);
+#else
+		fexec(PKG_DELETE, "-f", premove->depname, NULL);
+#endif
+	}
+}
+
 /* package installation. Don't rely on pkg_add's ability to fetch and
  * install as we want to keep control on packages installation order.
  * Besides, pkg_add cannot be used to install an "older" package remotely
@@ -157,6 +151,11 @@ do_pkg_install(Deptreehead *installhead)
 	Pkgdeptree	*pinstall;
 	char		pkgpath[BUFSIZ];
 
+/* send pkg_add stderr to logfile */
+#ifdef HAVE_FREOPEN
+	(void)freopen(PKGIN_ERR_LOG, "a", stderr);
+#endif
+
 	printf(MSG_INSTALL_PKG);
 
 	SLIST_FOREACH(pinstall, installhead, next) {
@@ -355,7 +354,7 @@ pkg_has_conflicts(Plisthead *conflictshead, Pkgimpact *pimpact)
 #define H_BUF 6
 
 int
-pkgin_install(char **pkgargs)
+pkgin_install(char **pkgargs, uint8_t do_inst)
 {
 	int			installnum = 0, upgradenum = 0, removenum = 0;
 	int			rc = EXIT_FAILURE;
@@ -473,19 +472,21 @@ pkgin_install(char **pkgargs)
 			/* before erasing anything, download packages */
 			pkg_download(installhead);
 
-			/* if there was upgrades, first remove old packages */
-			if (upgradenum > 0) {
-				printf(MSG_RM_UPGRADE_PKGS);
-				do_pkg_remove(removehead);
+			if (do_inst) { /* real install, not a simple download */
+				/* if there was upgrades, first remove old packages */
+				if (upgradenum > 0) {
+					printf(MSG_RM_UPGRADE_PKGS);
+					do_pkg_remove(removehead);
+				}
+				/* then pass ordered install list */
+				do_pkg_install(installhead);
+
+				/* pure install, not called by pkgin_upgrade */
+				if (upgrade_type == UPGRADE_NONE)
+					update_db(LOCAL_SUMMARY, pkgargs);
+				
+				rc = EXIT_SUCCESS;
 			}
-			/* then pass ordered install list */
-			do_pkg_install(installhead);
-
-			/* pure install, not called by pkgin_upgrade */
-			if (upgrade_type == UPGRADE_NONE)
-				update_db(LOCAL_SUMMARY, pkgargs);
-
-			rc = EXIT_SUCCESS;
 		}
 	} else
 		printf(MSG_NOTHING_TO_INSTALL);
@@ -691,7 +692,7 @@ pkgin_upgrade(int uptype)
 
 	pkgargs = record_upgrades(localplisthead, remoteplisthead);
 
-	if (pkgin_install(pkgargs) == EXIT_SUCCESS) {
+	if (pkgin_install(pkgargs, DO_INST) == EXIT_SUCCESS) {
 		/*
 		 * full upgrade, we need to record keep-packages
 		 * in order to restore them
