@@ -1,4 +1,4 @@
-/* $Id: impact.c,v 1.28.2.1.2.6 2011/01/20 15:00:29 imil Exp $ */
+/* $Id: impact.c,v 1.39 2011/02/09 21:34:37 imil Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -248,14 +248,18 @@ deps_impact(Impacthead *impacthead,
 
 		/* match, package is installed */
 		if (strncmp(localmatch, matchname, strlen(localmatch)) == 0) {
+
 			/* default action when local package match */
 			toupgrade = TOUPGRADE;
-			/* installed version does not match dep requirement */
-			if (!pkg_match(pdp->depname, plist->pkgname)) {
+
+			/* installed version does not match dep requirement
+			 * OR force reinstall, pkgkeep being use to inform -F was given
+			 */
+			if (!pkg_match(pdp->depname, plist->pkgname) || pdp->pkgkeep < 0) {
+
 				/* local pkgname didn't match deps, remote pkg has a
 				 * lesser version than local package.
 				*/
-
 				if (version_check(plist->pkgname, remotepkg) == 1) {
 					/*
 					 * proposing a downgrade is definitely not useful,
@@ -385,6 +389,7 @@ count_samepkg(Plisthead *plisthead, const char *pkgname)
 	return count;
 }
 
+/* is pkgname already in impact list ? */
 static uint8_t
 pkg_in_impact(Impacthead *impacthead, char *pkgname)
 {
@@ -400,6 +405,7 @@ pkg_in_impact(Impacthead *impacthead, char *pkgname)
 Impacthead *
 pkg_impact(char **pkgargs)
 {
+	static char	*icon = ICON_WAIT;
 	Plisthead	*localplisthead;
 	Plisthead	*remoteplisthead;
 	Deptreehead	pdphead;
@@ -407,6 +413,9 @@ pkg_impact(char **pkgargs)
 	Pkgimpact	*pimpact, *tmpimpact;
 	Pkgdeptree	*pdp;
 	char		**ppkgargs, *pkgname = NULL;
+#ifndef DEBUG
+	char		tmpicon;
+#endif
 	int			pkgcount;
 
 	/* record local package list */
@@ -446,7 +455,15 @@ pkg_impact(char **pkgargs)
 		if (pkgcount > 1)
 			goto impactend;
 		else {
+#ifndef DEBUG
+			tmpicon = *icon++;
+			printf(MSG_CALCULATING_DEPS" %c", tmpicon);
+			fflush(stdout);
+			if (*icon == '\0')
+				icon = icon - strlen(ICON_WAIT);
+#else
 			printf(MSG_CALCULATING_DEPS, *ppkgargs);
+#endif
 			/* dependencies discovery */
 			full_dep_tree(*ppkgargs, DIRECT_DEPS, &pdphead);
 		}
@@ -481,10 +498,21 @@ pkg_impact(char **pkgargs)
 		XSTRDUP(pdp->matchname, pkgname);
 		trunc_str(pdp->matchname, '-', STR_BACKWARD);
 
+		/* pkgname is not already recorded */
 		if (!pkg_in_impact(impacthead, pkgname)) {
 			/* passing pkgname as depname */
 			XSTRDUP(pdp->depname, pkgname);
 
+			/* reset pkgkeep */
+			pdp->pkgkeep = 0;
+
+			if (force_reinstall)
+				/* use pkgkeep field to inform deps_impact the package
+				 * has to be reinstalled. It is NOT the normal use for
+				 * the pkgkeep field, it is just used as a temporary field
+				 */
+				pdp->pkgkeep = -1;
+
 			deps_impact(impacthead, localplisthead, remoteplisthead, pdp);
 
 			XFREE(pdp->depname);
@@ -497,6 +525,10 @@ pkg_impact(char **pkgargs)
 
 	} /* for (ppkgargs) */
 
+#ifndef DEBUG
+	printf(MSG_CALCULATING_DEPS" done.\n");
+#endif
+
 impactend:
 
 	free_deptree(&pdphead);
