@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.17.2.1 2011/01/16 12:38:14 imil Exp $ */
+/* $Id: main.c,v 1.30 2011/02/06 11:29:59 imil Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -39,26 +39,31 @@ static void	split_repos(void);
 static int	find_cmd(const char *);
 static void	missing_param(int, int, const char *);
 
-int 		yesflag = 0, noflag = 0, force_update = 0;
+int 		yesflag = 0, noflag = 0, force_update = 0, force_reinstall = 0;
 char		*env_repos, **pkg_repos;
 char		lslimit = '\0';
 
 int
 main(int argc, char *argv[])
 {
+	uint8_t		do_inst = DO_INST; /* by default, do install packages */
 	int 		ch;
 	struct stat	sb;
+	const char	*chrootpath = NULL;
 
 	setprogname(argv[0]);
 
 	if (argc < 2)
 		usage();
 
-	while ((ch = getopt(argc, argv, "hyfvl:n")) != -1) {
+	while ((ch = getopt(argc, argv, "dhyfFvl:nc:")) != -1) {
 		switch (ch) {
 		case 'f':
 			force_update = 1;
 			break;
+		case 'F':
+			force_reinstall = 1;
+			break;
 		case 'y':
 			yesflag = 1;
 			noflag = 0;
@@ -68,7 +73,8 @@ main(int argc, char *argv[])
 			noflag = 1;
 			break;
 		case 'v':
-			printf("%s %s\n", getprogname(), PKGIN_VERSION);
+			printf("%s %s (using %s)\n", 
+				getprogname(), PKGIN_VERSION, pdb_version());
 			exit(EXIT_SUCCESS);
 			/* NOTREACHED */
 		case 'h':
@@ -77,6 +83,12 @@ main(int argc, char *argv[])
 		case 'l':
 			lslimit = optarg[0];
 			break;
+		case 'd':
+			do_inst = DONT_INST; /* download only */
+			break;
+		case 'c':
+			chrootpath = optarg;
+			break;
 		default:
 			usage();
 			/* NOTREACHED */
@@ -93,6 +105,15 @@ main(int argc, char *argv[])
 
 	/* initializations */
 
+	/* enter chroot if -c specified */
+	if (chrootpath != NULL) {
+		if (chroot(chrootpath) == -1)
+			errx(-1, MSG_CHROOT_FAILED);
+
+		if (chdir("/") == -1)
+			errx(-1, MSG_CHDIR_FAILED);
+	}
+
 	/* for pkg_install */
 	unsetenv("PKG_PATH");
 	/* create base directories */
@@ -137,7 +158,7 @@ main(int argc, char *argv[])
 			break;
 		case PKG_INST_CMD:
 			missing_param(argc, 2, MSG_PKG_ARGS_INST);
-			pkgin_install(&argv[1]);
+			pkgin_install(&argv[1], do_inst);
 			break;
 		case PKG_UPGRD_CMD:
 			pkgin_upgrade(UPGRADE_KEEP);
