@@ -1,4 +1,4 @@
-/* $Id: messages.h,v 1.8.2.1.2.3 2011/01/18 13:52:46 imil Exp $ */
+/* $Id: messages.h,v 1.29 2011/02/09 21:34:37 imil Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -41,9 +41,11 @@
 #define MSG_PKG_ARGS_UNKEEP "specify at least one package to unkeep"
 #define MSG_MISSING_SRCH "missing search string"
 
-#define MSG_USAGE "Usage: %s [-fhlnvy] command [package ...]\n"
+#define MSG_USAGE "Usage: %s [-cdfFhlnvy] command [package ...]\n"
 #define MSG_CMDS_SHORTCUTS "\nCommands and shortcuts:\n"
 
+#define MSG_CHROOT_FAILED "Unable to chroot"
+#define MSG_CHDIR_FAILED "Unable to chroot"
 
 #define MSG_MISSING_PKG_REPOS \
 	PKGIN_CONF"/"REPOS_FILE" has no repositories or does not exist.\nNo PKG_REPOS variable to fallback to."
@@ -86,7 +88,7 @@
 
 /* download.c */
 #define MSG_DOWNLOADING "downloading %s:   0%%"
-#define MSG_DOWNLOADING_PCT "\b\b\b\b%3d%%"
+#define MSG_DOWNLOADING_PCT "\rdownloading %s: %8s %3d%%"
 
 /* autoremove.c */
 #define MSG_AUTOREMOVE_WARNING "\
@@ -106,6 +108,7 @@ in order to remove packages from the autoremove list, flag those with the -k mod
 #define MSG_DB_IS_UP_TO_DATE "database for %s is up-to-date\n"
 #define MSG_PROCESSING_REMOTE_SUMMARY "processing remote summary (%s)...\n"
 #define MSG_COULDNT_FETCH "Could not fetch %s\n"
+#define MSG_ARCH_DONT_MATCH "\r\n/!\\ Warning /!\\ %s doesn't match your current architecture (%s)\nYou probably want to modify "PKGIN_CONF"/"REPOS_FILE".\nStill want to "
 
 /* impact.c */
 #define MSG_GREATER_VERSION \
@@ -113,8 +116,12 @@ in order to remove packages from the autoremove list, flag those with the -k mod
 #define MSG_MORE_THAN_ONE_VER \
 	"there's more than one version available for this package.\n\
 please re-run %s with a package name matching one of the following:\n"
+#ifndef DEBUG
 #define MSG_PKG_NOT_AVAIL "%s is not available on the repository\n"
+#else
 #define MSG_CALCULATING_DEPS "calculating dependencies for %s...\n"
+#endif
+#define MSG_CALCULATING_DEPS "\rcalculating dependencies..."
 #define MSG_BROKEN_DEP "%s has no dependency in pkg_summary(5), while it's a reverse dependency for %s (missing package in repository ?). Default behaviour is to remove %s. "
 
 /* pkglist.c */
