@@ -1,4 +1,4 @@
-/* $Id: tools.c,v 1.3.2.1 2011/01/16 12:38:14 imil Exp $ */
+/* $Id: tools.c,v 1.15 2011/01/30 15:44:53 imil Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -229,7 +229,11 @@ getosrelease(void)
 	if (uname(&un) < 0)
 		return NULL;
 
+#ifdef _MINIX
+	asprintf(&ret, "%s.%s", un.release, un.version);
+#else
 	XSTRDUP(ret, un.release);
+#endif
 
 	for (p = ret; isdigit((int)*p) || *p == '.'; p++);
 	*p = '\0';
